Control
=============================

.. currentmodule:: enaml.widgets.control

.. autoclass:: Control


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_control.QtControl
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_control.QtControl

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_control.WXControl
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_control.WXControl
